@@ -1,15 +1,17 @@
 package Random::Any;
 
-our $DATE = '2018-04-18'; # DATE
-our $VERSION = '0.004'; # VERSION
-
 use strict 'subs', 'vars';
 #use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2025-01-07'; # DATE
+our $DIST = 'Random-Any'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 my $warn;
 my $sub;
 
-sub rand(;$) {
+sub rand(;$) { ## no critic: Subroutines::ProhibitSubroutinePrototypes
     $sub->(@_);
 }
 
@@ -30,6 +32,7 @@ sub import {
     }
 
     $warn = $ENV{PERL_RANDOM_ANY_WARN} unless defined $warn;
+    $warn = 1 unless defined $warn;
 
     unless ($sub) {
         if (eval { require Data::Entropy::Algorithms; 1 }) {
@@ -56,7 +59,7 @@ Random::Any - Try to use Data::Entropy::Algorithms::rand(), fallback on builtin
 
 =head1 VERSION
 
-This document describes version 0.004 of Random::Any (from Perl distribution Random-Any), released on 2018-04-18.
+This document describes version 0.005 of Random::Any (from Perl distribution Random-Any), released on 2025-01-07.
 
 =head1 SYNOPSIS
 
@@ -68,14 +71,28 @@ This document describes version 0.004 of Random::Any (from Perl distribution Ran
 
 This module provides a single export C<rand()> that tries to use
 L<Data::Entropy::Algorithms>'s C<rand()> first and, if that module is not
-available, falls back on the builtin rand().
+available, warns to STDERR and falls back on the builtin C<rand()>.
+
+Note that whenever you can you are encouraged to use C<rand_int()> or
+C<random_int()>, or C<rand_flt()> or C<random_float()> function instead. From
+C<Data::Entropy::Algorithm>'s documentation:
+
+"This function should not be used in any new code, because the kind of output
+supplied by C<rand> is hardly ever the right thing to use. The C<int(rand($n))>
+idiom to generate a random integer has non-uniform probabilities of generating
+each possible value, except when C<$n> is a power of two. For floating point
+numbers, C<rand> can't generate most representable numbers in its output range,
+and the output is biased towards zero. In new code use C<rand_int> to generate
+integers and "rand_flt" to generate floating point numbers."
+
+Also, take a look at L<Random::Simple> instead of this module.
 
 =head1 EXPORTS
 
 =head2 -warn => bool
 
-Can be set to true to emit a warning if Data::Entropy::Algorithms is not
-available.
+If true (the default) then emit a warning if Data::Entropy::Algorithms is not
+available. To disable this warning, set to false.
 
 =head1 FUNCTIONS
 
@@ -93,7 +110,42 @@ Please visit the project's homepage at L<https://metacpan.org/release/Random-Any
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com///git@github.com/perlancar/perl-Random-Any>.
+Source repository is at L<https://github.com/perlancar/perl-Random-Any>.
+
+=head1 SEE ALSO
+
+L<Data::Entropy::Algorithms>
+
+L<Random::Simple>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS
 
@@ -103,19 +155,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<Data::Entropy::Algorithms>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2018 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
